@@ -1,6 +1,6 @@
 /*  
  *  Global Time - Set of clocks showing time in different parts of world.
- *  Copyright 2006 Juha Kautto (kautto.juha@kolumbus.fi)
+ *  Copyright 2006-2011 Juha Kautto (kautto.juha@kolumbus.fi)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,11 +45,11 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libxfce4util/libxfce4util.h>
 #include "globaltime.h"
+#include "../src/orage-i18n.h"
 
 
-#define NAME_VERSION "Global Time (2.0)"
+#define NAME_VERSION "Global Time (2.1)"
 
 
 global_times_struct clocks;
@@ -106,7 +106,7 @@ static gboolean global_time_active_already(GdkAtom *atom)
         return(FALSE); 
 }
 
-static void show_globaltime()
+static void raise_window(void)
 {
     GdkWindow *window;
 
@@ -116,6 +116,7 @@ static void show_globaltime()
     window = GTK_WIDGET(clocks.window)->window;
     gdk_x11_window_set_user_time(window, gdk_x11_get_server_time(window));
     gtk_widget_show(clocks.window);
+    gtk_window_present(GTK_WINDOW(clocks.window));
 }
 
 static gboolean client_message_received(GtkWidget *widget
@@ -123,9 +124,7 @@ static gboolean client_message_received(GtkWidget *widget
 {
     if (event->message_type == 
             gdk_atom_intern("_XFCE_GLOBALTIME_RAISE", FALSE)) {
-        /* we need to hide it first since minimized windows are visible ! */
-        gtk_widget_hide(clocks.window); 
-        show_globaltime();
+        raise_window();
         return(TRUE);
     }
     else if (event->message_type ==
@@ -134,7 +133,7 @@ static gboolean client_message_received(GtkWidget *widget
             gtk_widget_hide(clocks.window);
             return(TRUE);
         }
-        show_globaltime();
+        raise_window();
         return(TRUE);
     }
                                                                                 
@@ -342,6 +341,8 @@ void show_clock(clock_struct *clockp, gint *pos)
 static gboolean preferences_button_pressed(GtkWidget *widget
         , GdkEventButton *event, gpointer dummy)
 {
+    struct tm *now;
+
     if (event->button == 2) { /* toggle spinbox sensitivity */
         if (clocks.time_adj_act) { /* end it */
             gtk_widget_hide(clocks.hdr_adj_mm);
@@ -355,15 +356,19 @@ static gboolean preferences_button_pressed(GtkWidget *widget
             clocks.mm_adj = 0;
             clocks.hh_adj = 0;
             clocks.previous_secs = 70; /* trick to refresh clocks once */
-            g_message(_("Ending time adjustment mode"));
             gtk_window_resize(GTK_WINDOW(clocks.window), 10, 10);
         }
         else { /* start hour adjusting mode */
+            /* let's try to guess good starting value = to get times to 
+             * 0 or 30 minutes. */
+            now = gmtime(&clocks.previous_t);
+            clocks.mm_adj = (now->tm_min < 30 ? 0 : 60) - now->tm_min;
+            gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_mm)
+                    , (gdouble)clocks.mm_adj);
             gtk_widget_show(clocks.hdr_adj_mm);
             gtk_widget_show(clocks.hdr_adj_sep);
             gtk_widget_show(clocks.hdr_adj_hh);
             clocks.time_adj_act = TRUE;
-            g_message(_("Starting time adjustment mode"));
         }
         return(FALSE);
     }
@@ -385,7 +390,7 @@ static void add_default_clock(void)
     write_file();
 }
 
-void upd_clock(clock_struct *clockp)
+static void upd_clock(clock_struct *clockp)
 {
     struct tm *now;
 
@@ -408,6 +413,9 @@ static gboolean upd_clocks(void)
     struct tm *now;
     gint secs_now;
 
+    if (clocks.no_update)
+        return(TRUE);
+
     now = get_time(clocks.local_tz->str); /* GMT is returmed if not found */
     if (!clocks.time_adj_act) {
         time(&clocks.previous_t);
@@ -424,15 +432,15 @@ static gboolean upd_clocks(void)
         /* minute changed => need to update visible clocks */
         g_list_foreach(clocks.clock_list, (GFunc) upd_clock, NULL);
     clocks.previous_secs = secs_now;
-    return (TRUE);
+    return(TRUE);
 }
 
-void adj_hh_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_hh_changed(GtkSpinButton *cb, gpointer user_data)
 {
     clocks.hh_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
 
-void adj_mm_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_mm_changed(GtkSpinButton *cb, gpointer user_data)
 {
     clocks.mm_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
@@ -462,12 +470,12 @@ static void init_hdr_button(void)
     gtk_widget_show(image);
     gtk_widget_show(clocks.hdr_button);
 
-    clocks.hdr_adj_hh = gtk_spin_button_new_with_range(-23, 23, 1);
+    clocks.hdr_adj_hh = gtk_spin_button_new_with_range(-24, 24, 1);
     gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
             , clocks.hdr_adj_hh, FALSE, FALSE, 0);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), TRUE);
-    gtk_widget_set_size_request(clocks.hdr_adj_hh, 40, -1);
+    gtk_widget_set_size_request(clocks.hdr_adj_hh, 45, -1);
     gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_hh
             , _("adjust to change hour"), NULL);
     g_signal_connect((gpointer) clocks.hdr_adj_hh, "changed"
@@ -477,14 +485,15 @@ static void init_hdr_button(void)
     gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
             , clocks.hdr_adj_sep, FALSE, FALSE, 0);
 
-    clocks.hdr_adj_mm = gtk_spin_button_new_with_range(-59, 59, 1);
+    clocks.hdr_adj_mm = gtk_spin_button_new_with_range(-60, 60, 1);
     gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
             , clocks.hdr_adj_mm, FALSE, FALSE, 0);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), TRUE);
-    gtk_widget_set_size_request(clocks.hdr_adj_mm, 40, -1);
+    gtk_spin_button_set_increments(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), 30, 1);
+    gtk_widget_set_size_request(clocks.hdr_adj_mm, 45, -1);
     gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_mm
-            , _("adjust to change minute"), NULL);
+            , _("adjust to change minute. Click arrows with button 2 to change only 1 minute."), NULL);
     g_signal_connect((gpointer) clocks.hdr_adj_mm, "changed"
             , G_CALLBACK(adj_mm_changed), NULL);
     /* We want it to be hidden initially, it is special thing to do...
@@ -499,7 +508,20 @@ static gboolean clean_up(GtkObject *obj, GdkEvent *event, gint g)
     return(FALSE);
 }
 
-static void initialize_clocks()
+static void create_icon(void)
+{
+    GdkPixbuf *clock_logo;
+    GtkIconTheme *icon_theme;
+
+    icon_theme = gtk_icon_theme_get_default();
+    clock_logo = gtk_icon_theme_load_icon(icon_theme, "orage_globaltime", 0
+            , GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
+    gtk_window_set_default_icon(clock_logo);
+    gtk_window_set_icon(GTK_WINDOW(clocks.window), clock_logo);
+    g_object_unref(clock_logo);
+}
+
+static void initialize_clocks(void)
 {
     GtkWidget *button;
 
@@ -507,6 +529,7 @@ static void initialize_clocks()
     strcpy(clocks.time_now, "88:88");
     clocks.previous_secs = 61;      
     clocks.time_adj_act = FALSE;      
+    clocks.no_update = FALSE;
     clocks.hh_adj = 0;      
     clocks.mm_adj = 0;      
     /* done in read_file
@@ -581,7 +604,7 @@ static void create_global_time(void)
     }
 
     initialize_clocks();
-
+    create_icon();
     read_file(); /* fills clock_list non GTK members */
 
     if (g_list_length(clocks.clock_list) == 0)
@@ -604,8 +627,14 @@ static void create_global_time(void)
 
 int main(int argc, char *argv[])
 {
-    xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
-    gtk_init (&argc, &argv);
+    /* init i18n = nls to use gettext */
+    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+#endif
+    textdomain(GETTEXT_PACKAGE);
+
+    gtk_init(&argc, &argv);
     create_global_time();
     gtk_main();
 
