@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2004-2005 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -56,7 +56,7 @@
 */
 
 
-gboolean orage_mark_appointments()
+gboolean orage_mark_appointments(void)
 {
 #undef P_N
 #define P_N "orage_mark_appointments: "
@@ -74,16 +74,15 @@ static void mFile_newApp_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
 {
 #undef P_N
 #define P_N "mFile_newApp_activate_cb: "
-    struct tm *t;
+    CalWin *cal = (CalWin *)user_data;
     char cur_date[9];
 
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    t = orage_localtime();
-    g_snprintf(cur_date, 9, "%04d%02d%02d", t->tm_year+1900
-            , t->tm_mon+1, t->tm_mday);
-    create_appt_win("NEW", cur_date);  
+    /* cal has always a day selected here, so it is safe to read it */
+    strcpy(cur_date, orage_cal_to_icaldate(GTK_CALENDAR(cal->mCalendar)));
+    create_appt_win("NEW", cur_date);
 }
 
 static void mFile_interface_activate_cb(GtkMenuItem *menuitem
@@ -169,21 +168,40 @@ static void mView_selectToday_activate_cb(GtkMenuItem *menuitem
     orage_select_today(GTK_CALENDAR(cal->mCalendar));
 }
 
+static void mView_StartGlobaltime_activate_cb(GtkMenuItem *menuitem
+        , gpointer user_data)
+{
+#undef P_N
+#define P_N "mView_StartGlobaltime_activate_cb: "
+    GError *error = NULL;
+
+#ifdef ORAGE_DEBUG
+    orage_message(-100, P_N);
+#endif
+    if (!orage_exec("globaltime", FALSE, &error))
+        orage_message(100, "%s: start of %s failed: %s", "Orage", "globaltime"
+                , error->message);
+}
+
 static void mHelp_help_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
 {
 #undef P_N
 #define P_N "mHelp_help_activate_cb: "
     gchar *helpdoc;
+    GError *error = NULL;
 
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    helpdoc = g_strconcat("xfbrowser4 ", PACKAGE_DATA_DIR
+    helpdoc = g_strconcat("firefox ", PACKAGE_DATA_DIR
            , G_DIR_SEPARATOR_S, "orage"
            , G_DIR_SEPARATOR_S, "doc"
            , G_DIR_SEPARATOR_S, "C"
-           , G_DIR_SEPARATOR_S, "orage.html", NULL);
-    orage_exec(helpdoc, NULL, NULL);
+           , G_DIR_SEPARATOR_S, "orage.html"
+           , NULL);
+    if (!orage_exec(helpdoc, FALSE, &error))
+        orage_message(100, "start of %s failed: %s", helpdoc, error->message);
+    g_free(helpdoc);
 }
 
 static void mHelp_about_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
@@ -241,7 +259,7 @@ void mCalendar_month_changed_cb(GtkCalendar *calendar, gpointer user_data)
         g_source_remove(timer);
     if (calendar->num_marked_dates) /* undocumented, internal field; ugly */
         gtk_calendar_clear_marks(calendar);
-    timer = g_timeout_add(500, (GtkFunction)upd_calendar, calendar);
+    timer = g_timeout_add(400, (GtkFunction)upd_calendar, calendar);
 }
 
 static void build_menu(void)
@@ -299,6 +317,12 @@ static void build_menu(void)
             orage_menu_item_new_with_mnemonic(_("Select _Today")
                     , cal->mView_menu);
 
+    menu_separator = orage_separator_menu_item_new(cal->mView_menu);
+
+    cal->mView_StartGlobaltime = 
+            orage_menu_item_new_with_mnemonic(_("Show _Globaltime")
+                    , cal->mView_menu);
+
     /* Help menu */
     cal->mHelp_menu = orage_menu_new(_("_Help"), cal->mMenubar);
     cal->mHelp_help = orage_image_menu_item_new_from_stock("gtk-help"
@@ -325,6 +349,8 @@ static void build_menu(void)
             , G_CALLBACK(mView_ViewSelectedWeek_activate_cb),(gpointer) cal);
     g_signal_connect((gpointer) cal->mView_selectToday, "activate"
             , G_CALLBACK(mView_selectToday_activate_cb),(gpointer) cal);
+    g_signal_connect((gpointer) cal->mView_StartGlobaltime, "activate"
+            , G_CALLBACK(mView_StartGlobaltime_activate_cb),(gpointer) cal);
     g_signal_connect((gpointer) cal->mHelp_help, "activate"
             , G_CALLBACK(mHelp_help_activate_cb), NULL);
     g_signal_connect((gpointer) cal->mHelp_about, "activate"
@@ -353,9 +379,13 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
 #define P_N "add_info_row: "
     GtkWidget *ev, *label;
     CalWin *cal = (CalWin *)g_par.xfcal;
-    gchar *tip, *tmp;
+    gchar *tip, *tmp, *tmp_title, *tmp_note;
+#if GTK_CHECK_VERSION(2,16,0)
+    gchar *tip_title = NULL, *tip_location = NULL, *tip_note = NULL;
+    gchar *format_bold = "<span weight=\"bold\"> %s </span>";
+#endif
     struct tm *t;
-    char      *l_time, *s_time, *e_time, *c_time, *na;
+    char  *l_time, *s_time, *s_timeonly, *e_time, *c_time, *na, *today;
     gint  len;
 
 #ifdef ORAGE_DEBUG
@@ -363,7 +393,28 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
 #endif
     /***** add data into the vbox *****/
     ev = gtk_event_box_new();
-    tmp = g_strdup_printf("  %s", appt->title);
+    tmp_title = orage_process_text_commands(appt->title);
+    s_time = g_strdup(orage_icaltime_to_i18_time(appt->starttimecur));
+    if (todo) {
+        e_time = g_strdup(appt->use_due_time
+                ? orage_icaltime_to_i18_time(appt->endtimecur) : s_time);
+        tmp = g_strdup_printf(" %s  %s", e_time, tmp_title);
+        g_free(e_time);
+    }
+    else {
+        today = orage_tm_time_to_icaltime(orage_localtime());
+        s_timeonly = g_strdup(orage_icaltime_to_i18_time_only(
+                    appt->starttimecur));
+        if (!strncmp(today, appt->starttimecur, 8)) /* today */
+            tmp = g_strdup_printf(" %s* %s", s_timeonly, tmp_title);
+        else {
+            if (g_par.show_event_days > 1)
+                tmp = g_strdup_printf(" %s  %s", s_time, tmp_title);
+            else
+                tmp = g_strdup_printf(" %s  %s", s_timeonly, tmp_title);
+        }
+        g_free(s_timeonly);
+    }
     label = gtk_label_new(tmp);
     g_free(tmp);
     gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
@@ -395,30 +446,73 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
         g_free(e_time);
     }
 
-    /***** set hint *****/
-    s_time = g_strdup(orage_icaltime_to_i18_time(appt->starttimecur));
+    /***** set tooltip hint *****/
+    tmp_note = orage_process_text_commands(appt->note);
     if (todo) {
         na = _("Never");
         e_time = g_strdup(appt->use_due_time
                 ? orage_icaltime_to_i18_time(appt->endtimecur) : na);
         c_time = g_strdup(appt->completed
                 ? orage_icaltime_to_i18_time(appt->completedtime) : na);
-        tip = g_strdup_printf(_("Title: %s\n Start:\t%s\n Due:\t%s\n Done:\t%s\nNote:\n%s")
-                , appt->title, s_time, e_time, c_time, appt->note);
+#if GTK_CHECK_VERSION(2,16,0)
+        if (tmp_title) {
+            tip_title = g_markup_printf_escaped(format_bold, tmp_title);
+        }   
+        if (appt->location) {
+            tip_location = g_markup_printf_escaped(format_bold, appt->location);
+        }
+        if (tmp_note) {
+            tip_note = g_markup_escape_text(tmp_note, strlen(tmp_note));
+        }
+
+        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n Due:\t%s\n Done:\t%s\n Note:\n%s")
+                , tip_title, tip_location, s_time, e_time, c_time, tip_note);
+#else
+        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n Due:\t%s\n Done:\t%s\n Note:\n%s")
+                , tmp_title, appt->location, s_time, e_time, c_time, tmp_note);
+#endif
+
         g_free(c_time);
     }
     else { /* it is event */
         e_time = g_strdup(orage_icaltime_to_i18_time(appt->endtimecur));
-        tip = g_strdup_printf(_("Title: %s\n Start:\t%s\n End:\t%s\n Note:\n%s")
-                , appt->title, s_time, e_time, appt->note);
+#if GTK_CHECK_VERSION(2,16,0)
+        if (tmp_title) {
+            tip_title = g_markup_printf_escaped(format_bold, tmp_title);
+        }
+        if (appt->location) {
+            tip_location = g_markup_printf_escaped(format_bold, appt->location);
+        }
+        if (tmp_note) {
+            tip_note = g_markup_escape_text(tmp_note, strlen(tmp_note));
+        }
+
+        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n End:\t%s\n Note:\n%s")
+                , tip_title, tip_location, s_time, e_time, tip_note);
+#else
+        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n End:\t%s\n Note:\n%s")
+                , tmp_title, appt->location, s_time, e_time, tmp_note);
+#endif
     }
+#if GTK_CHECK_VERSION(2,16,0)
+    gtk_widget_set_tooltip_markup(ev, tip);
+    if (tip_title)
+        g_free(tip_title);
+    if (tip_location)
+        g_free(tip_location);
+    if (tip_note)
+        g_free(tip_note);
+#else
     gtk_tooltips_set_tip(cal->Tooltips, ev, tip, NULL);
+#endif
+    g_free(tmp_title);
+    g_free(tmp_note);
     g_free(s_time);
     g_free(e_time);
     g_free(tip);
 }
 
-static void insert_rows(GList **todo_list, char *a_day, xfical_type ical_type
+static void insert_rows(GList **list, char *a_day, xfical_type ical_type
         , gchar *file_type)
 {
 #undef P_N
@@ -433,14 +527,14 @@ static void insert_rows(GList **todo_list, char *a_day, xfical_type ical_type
          appt;
          appt = xfical_appt_get_next_on_day(a_day, FALSE, 0
                 , ical_type , file_type)) {
-        *todo_list = g_list_prepend(*todo_list, appt);
+        *list = g_list_prepend(*list, appt);
     }
 }
 
-static gint list_order(gconstpointer a, gconstpointer b)
+static gint event_order(gconstpointer a, gconstpointer b)
 {
 #undef P_N
-#define P_N "list_order: "
+#define P_N "event_order: "
     xfical_appt *appt1, *appt2;
 
 #ifdef ORAGE_DEBUG
@@ -452,23 +546,52 @@ static gint list_order(gconstpointer a, gconstpointer b)
     return(strcmp(appt1->starttimecur, appt2->starttimecur));
 }
 
+static gint todo_order(gconstpointer a, gconstpointer b)
+{
+#undef P_N
+#define P_N "todo_order: "
+    xfical_appt *appt1, *appt2;
+
+#ifdef ORAGE_DEBUG
+    orage_message(-100, P_N);
+#endif
+    appt1 = (xfical_appt *)a;
+    appt2 = (xfical_appt *)b;
+
+    if (appt1->use_due_time && !appt2->use_due_time)
+        return(-1);
+    if (!appt1->use_due_time && appt2->use_due_time)
+        return(1);
+
+    return(strcmp(appt1->endtimecur, appt2->endtimecur));
+}
+
 static void info_process(gpointer a, gpointer pbox)
 {
 #undef P_N
 #define P_N "info_process: "
-    xfical_appt *appt = (xfical_appt *)a;;
-    GtkBox *box = GTK_BOX(pbox);
+    xfical_appt *appt = (xfical_appt *)a;
+    GtkBox *box= GTK_BOX(pbox);
     CalWin *cal = (CalWin *)g_par.xfcal;
     gboolean todo;
 
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
+    /*
+    orage_message(100, "%s %s", P_N, appt->uid);
+    if (appt->freq == XFICAL_FREQ_HOURLY) {
+        orage_message(100, "%s %s", P_N, "HOURLY");
+        if (appt->priority >= g_par.priority_list_limit)
+            orage_message(100, "%s %s", P_N, " low priority HOURLY");
+    }
+    */
     if (pbox == cal->mTodo_rows_vbox)
         todo = TRUE;
     else
         todo = FALSE;
-    add_info_row(appt, box, todo);
+    if (appt->priority < g_par.priority_list_limit)
+        add_info_row(appt, box, todo);
     xfical_appt_free(appt);
 }
 
@@ -482,7 +605,7 @@ static void create_mainbox_todo_info(void)
     orage_message(-100, P_N);
 #endif
     cal->mTodo_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mTodo_vbox, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mTodo_vbox, TRUE, TRUE, 0);
     cal->mTodo_label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(cal->mTodo_label), _("<b>To do:</b>"));
     gtk_box_pack_start(GTK_BOX(cal->mTodo_vbox), cal->mTodo_label
@@ -500,23 +623,44 @@ static void create_mainbox_todo_info(void)
             GTK_SCROLLED_WINDOW(cal->mTodo_scrolledWin), cal->mTodo_rows_vbox);
 }
 
-static void create_mainbox_event_info(void)
+static void create_mainbox_event_info_box(void)
 {
 #undef P_N
-#define P_N "create_mainbox_event_info: "
+#define P_N "create_mainbox_event_info_box: "
     CalWin *cal = (CalWin *)g_par.xfcal;
-    gchar *tmp;
+    gchar *tmp, *tmp2, *tmp3;
+    struct tm tm_date_start, tm_date_end;
 
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
+    tm_date_start = orage_cal_to_tm_time(GTK_CALENDAR(cal->mCalendar), 1, 1);
+
     cal->mEvent_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mEvent_vbox, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mEvent_vbox, TRUE, TRUE, 0);
     cal->mEvent_label = gtk_label_new(NULL);
-    tmp = g_strdup_printf(_("<b>Events for %s:</b>")
-            , orage_cal_to_i18_date(GTK_CALENDAR(cal->mCalendar)));
-    gtk_label_set_markup(GTK_LABEL(cal->mEvent_label), tmp);
-    g_free(tmp);
+    if (g_par.show_event_days) {
+    /* bug 7836: we call this routine also with 0 = no event data at all */
+        if (g_par.show_event_days == 1) {
+            tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
+            tmp = g_strdup_printf(_("<b>Events for %s:</b>"), tmp2);
+            g_free(tmp2);
+        }
+        else {
+            int i;
+
+            tm_date_end = tm_date_start;
+            for (i = g_par.show_event_days-1; i; i--)
+                orage_move_day(&tm_date_end, 1);
+            tmp2 = g_strdup(orage_tm_date_to_i18_date(&tm_date_start));
+            tmp3 = g_strdup(orage_tm_date_to_i18_date(&tm_date_end));
+            tmp = g_strdup_printf(_("<b>Events for %s - %s:</b>"), tmp2, tmp3);
+            g_free(tmp2);
+            g_free(tmp3);
+        }
+        gtk_label_set_markup(GTK_LABEL(cal->mEvent_label), tmp);
+        g_free(tmp);
+    }
 
     gtk_box_pack_start(GTK_BOX(cal->mEvent_vbox), cal->mEvent_label
             , FALSE, FALSE, 0);
@@ -530,7 +674,8 @@ static void create_mainbox_event_info(void)
             , TRUE, TRUE, 0);
     cal->mEvent_rows_vbox = gtk_vbox_new(FALSE, 0);
     gtk_scrolled_window_add_with_viewport(
-            GTK_SCROLLED_WINDOW(cal->mEvent_scrolledWin), cal->mEvent_rows_vbox);
+            GTK_SCROLLED_WINDOW(cal->mEvent_scrolledWin)
+            , cal->mEvent_rows_vbox);
 }
 
 static void build_mainbox_todo_info(void)
@@ -568,7 +713,7 @@ static void build_mainbox_todo_info(void)
     if (todo_list) {
         gtk_widget_destroy(cal->mTodo_vbox);
         create_mainbox_todo_info();
-        todo_list = g_list_sort(todo_list, list_order);
+        todo_list = g_list_sort(todo_list, todo_order);
         g_list_foreach(todo_list, (GFunc)info_process
                 , cal->mTodo_rows_vbox);
         g_list_free(todo_list);
@@ -596,7 +741,7 @@ static void build_mainbox_event_info(void)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    if (g_par.show_events) {
+    if (g_par.show_event_days) {
         gtk_calendar_get_date(GTK_CALENDAR(cal->mCalendar)
                 , (unsigned int *)&tt.tm_year
                 , (unsigned int *)&tt.tm_mon
@@ -608,16 +753,24 @@ static void build_mainbox_event_info(void)
     
         ical_type = XFICAL_TYPE_EVENT;
         strcpy(file_type, "O00.");
+        /*
         insert_rows(&event_list, a_day, ical_type, file_type);
+        */
+        xfical_get_each_app_within_time(a_day, g_par.show_event_days
+                , ical_type, file_type, &event_list);
         for (i = 0; i < g_par.foreign_count; i++) {
             g_sprintf(file_type, "F%02d.", i);
+            /*
             insert_rows(&event_list, a_day, ical_type, file_type);
+            */
+            xfical_get_each_app_within_time(a_day, g_par.show_event_days
+                    , ical_type, file_type, &event_list);
         }
     }
     if (event_list) {
         gtk_widget_destroy(cal->mEvent_vbox);
-        create_mainbox_event_info();
-        event_list = g_list_sort(event_list, list_order);
+        create_mainbox_event_info_box();
+        event_list = g_list_sort(event_list, event_order);
         g_list_foreach(event_list, (GFunc)info_process
                 , cal->mEvent_rows_vbox);
         g_list_free(event_list);
@@ -638,6 +791,16 @@ static void mCalendar_day_selected_cb(GtkCalendar *calendar
     orage_message(-100, P_N);
 #endif
     /* rebuild the info for the selected date */
+    build_mainbox_event_box();
+}
+
+void build_mainbox_event_box(void)
+{
+#undef P_N
+#define P_N "build_mainbox_event_box: "
+#ifdef ORAGE_DEBUG
+    orage_message(-100, P_N);
+#endif
     if (!xfical_file_open(TRUE))
         return;
     build_mainbox_event_info();
@@ -662,11 +825,10 @@ void build_mainbox_info(void)
     build_mainbox_event_info();
 }
 
-void build_mainWin()
+void build_mainWin(void)
 {
 #undef P_N
 #define P_N "build_mainWin: "
-    GdkPixbuf *orage_logo;
     CalWin *cal = (CalWin *)g_par.xfcal;
     GdkColormap *pic1_cmap;
 
@@ -679,24 +841,14 @@ void build_mainWin()
     gdk_color_parse("blue", &cal->mBlue);
     gdk_colormap_alloc_color(pic1_cmap, &cal->mBlue, FALSE, TRUE);
 
-    /* using static icon here since this dynamic icon is not updated
-     * when date changes. Could be added, but not worth it.
-     * Dynamic icon is used in systray and about windows */
-    orage_logo = orage_create_icon(TRUE, 48, 48); 
     cal->mAccel_group = gtk_accel_group_new();
     cal->Tooltips = gtk_tooltips_new();
 
     gtk_window_set_title(GTK_WINDOW(cal->mWindow), _("Orage"));
     gtk_window_set_position(GTK_WINDOW(cal->mWindow), GTK_WIN_POS_NONE);
-    gtk_window_set_resizable(GTK_WINDOW(cal->mWindow), FALSE);
+    gtk_window_set_resizable(GTK_WINDOW(cal->mWindow), TRUE);
     gtk_window_set_destroy_with_parent(GTK_WINDOW(cal->mWindow), TRUE);
 
-    if (orage_logo != NULL) {
-        gtk_window_set_icon(GTK_WINDOW(cal->mWindow), orage_logo);
-        gtk_window_set_default_icon(orage_logo);
-        g_object_unref(orage_logo);
-    }
-
     /* Build the vertical box */
     cal->mVbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(cal->mWindow), cal->mVbox);
@@ -707,15 +859,17 @@ void build_mainWin()
 
     /* Build the calendar */
     cal->mCalendar = gtk_calendar_new();
-    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mCalendar, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(cal->mVbox), cal->mCalendar, FALSE, FALSE, 0);
+    /*
     gtk_calendar_set_display_options(GTK_CALENDAR(cal->mCalendar)
             , GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_SHOW_DAY_NAMES
             | GTK_CALENDAR_SHOW_WEEK_NUMBERS);
+    */
     gtk_widget_show(cal->mCalendar);
 
     /* Build the Info boxes */
     create_mainbox_todo_info();
-    create_mainbox_event_info();
+    create_mainbox_event_info_box();
 
     /* Signals */
     g_signal_connect((gpointer) cal->mCalendar, "day_selected_double_click"
@@ -730,6 +884,9 @@ void build_mainWin()
 
     gtk_window_add_accel_group(GTK_WINDOW(cal->mWindow), cal->mAccel_group);
 
+    if (g_par.size_x || g_par.size_y)
+        gtk_window_set_default_size(GTK_WINDOW(cal->mWindow)
+                , g_par.size_x, g_par.size_y);
     if (g_par.pos_x || g_par.pos_y)
         gtk_window_move(GTK_WINDOW(cal->mWindow), g_par.pos_x, g_par.pos_y);
     /*
